@@ -1,5 +1,5 @@
 #!/usr/bin/python -OO
-# Copyright 2008-2010 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2011 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,18 +23,15 @@ import os
 import logging
 import threading
 import sabnzbd.misc
-import sabnzbd.constants as constants
+from sabnzbd.constants import CONFIG_VERSION, NORMAL_PRIORITY, DEFAULT_PRIORITY
 from sabnzbd.utils import listquote
 from sabnzbd.utils import configobj
 from sabnzbd.decorators import synchronized
-from sabnzbd.lang import Ta
 
 CONFIG_LOCK = threading.Lock()
 SAVE_CONFIG_LOCK = threading.Lock()
 
 
-__CONFIG_VERSION = '18'     # Minumum INI file version required
-
 CFG = {}                    # Holds INI structure
                             # uring re-write this variable is global allow
                             # direct access to INI structure
@@ -45,7 +42,7 @@ modified = False            # Signals a change in option dictionary
                             # Should be reset after saving to settings file
 
 
-class Option:
+class Option(object):
     """ Basic option class, basic fields """
     def __init__(self, section, keyword, default_val=None, add=True):
         """ Basic option
@@ -71,6 +68,10 @@ class Option:
                 anchor = anchor[section]
             anchor[keyword] = self
 
+    def __call__(self):
+        """ get() replacement """
+        return self.get()
+
     def get(self):
         """ Retrieve value field """
         if self.__value != None:
@@ -204,6 +205,12 @@ class OptionDir(Option):
                 self._Option__set(value)
         return error
 
+    def set_create(self):
+        """ Enable auto-creation and create now """
+        self.__create = True
+        self.get_path()
+
+
 class OptionList(Option):
     """ List option class """
     def __init__(self, section, keyword, default_val=None, validation=None, add=True):
@@ -237,7 +244,6 @@ class OptionList(Option):
         return txt
 
 
-
 class OptionStr(Option):
     """ String class """
     def __init__(self, section, keyword, default_val='', validation=None, add=True, strip=True):
@@ -299,15 +305,17 @@ class OptionPassword(Option):
 
 
 @synchronized(CONFIG_LOCK)
-def add_to_database(section, keyword, object):
+def add_to_database(section, keyword, obj):
+    """ add object as secion/keyword to INI database """
     global database
     if section not in database:
         database[section] = {}
-    database[section][keyword] = object
+    database[section][keyword] = obj
 
 
 @synchronized(CONFIG_LOCK)
 def delete_from_database(section, keyword):
+    """ Remove section/keyword from INI database """
     global database, CFG, modified
     del database[section][keyword]
     try:
@@ -317,7 +325,7 @@ def delete_from_database(section, keyword):
     modified = True
 
 
-class ConfigServer:
+class ConfigServer(object):
     """ Class defining a single server """
     def __init__(self, name, values):
 
@@ -334,6 +342,7 @@ class ConfigServer:
         self.ssl = OptionBool(name, 'ssl', False, add=False)
         self.enable = OptionBool(name, 'enable', True, add=False)
         self.optional = OptionBool(name, 'optional', False, add=False)
+        self.retention = OptionNumber(name, 'retention', add=False)
 
         self.set_dict(values)
         add_to_database('servers', self.__name, self)
@@ -341,7 +350,7 @@ class ConfigServer:
     def set_dict(self, values):
         """ Set one or more fields, passed as dictionary """
         for kw in ('host', 'port', 'timeout', 'username', 'password', 'connections',
-                   'fillserver', 'ssl', 'enable', 'optional'):
+                   'fillserver', 'ssl', 'enable', 'optional', 'retention'):
             try:
                 value = values[kw]
             except KeyError:
@@ -353,19 +362,20 @@ class ConfigServer:
         """ Return a dictionary with all attributes """
         dict = {}
         dict['name'] = self.__name
-        dict['host'] = self.host.get()
-        dict['port'] = self.port.get()
-        dict['timeout'] = self.timeout.get()
-        dict['username'] = self.username.get()
+        dict['host'] = self.host()
+        dict['port'] = self.port()
+        dict['timeout'] = self.timeout()
+        dict['username'] = self.username()
         if safe:
             dict['password'] = self.password.get_stars()
         else:
-            dict['password'] = self.password.get()
-        dict['connections'] = self.connections.get()
-        dict['fillserver'] = self.fillserver.get()
-        dict['ssl'] = self.ssl.get()
-        dict['enable'] = self.enable.get()
-        dict['optional'] = self.optional.get()
+            dict['password'] = self.password()
+        dict['connections'] = self.connections()
+        dict['fillserver'] = self.fillserver()
+        dict['ssl'] = self.ssl()
+        dict['enable'] = self.enable()
+        dict['optional'] = self.optional()
+        dict['retention'] = self.retention()
         return dict
 
     def delete(self):
@@ -382,7 +392,7 @@ class ConfigServer:
         return 'servers', self.__name
 
 
-class ConfigCat:
+class ConfigCat(object):
     """ Class defining a single category """
     def __init__(self, name, values):
         self.__name = name
@@ -392,7 +402,7 @@ class ConfigCat:
         self.script = OptionStr(name, 'script', 'Default', add=False)
         self.dir = OptionDir(name, 'dir', add=False, create=False)
         self.newzbin = OptionList(name, 'newzbin', add=False)
-        self.priority = OptionNumber(name, 'priority', constants.DEFAULT_PRIORITY, add=False)
+        self.priority = OptionNumber(name, 'priority', DEFAULT_PRIORITY, add=False)
 
         self.set_dict(values)
         add_to_database('categories', self.__name, self)
@@ -411,11 +421,11 @@ class ConfigCat:
         """ Return a dictionary with all attributes """
         dict = {}
         dict['name'] = self.__name
-        dict['pp'] = self.pp.get()
-        dict['script'] = self.script.get()
-        dict['dir'] = self.dir.get()
+        dict['pp'] = self.pp()
+        dict['script'] = self.script()
+        dict['dir'] = self.dir()
         dict['newzbin'] = self.newzbin.get_string()
-        dict['priority'] = self.priority.get()
+        dict['priority'] = self.priority()
         return dict
 
     def delete(self):
@@ -480,11 +490,13 @@ class OptionFilters(Option):
                     filters.append(val)
                 else:
                     filters.append(listquote.simplelist(val))
+                while len(filters[-1]) < 6:
+                    filters[-1].append('')
         if filters:
             self.set(filters)
         return True
 
-class ConfigRSS:
+class ConfigRSS(object):
     """ Class defining a single Feed definition """
     def __init__(self, name, values):
         self.__name = name
@@ -495,9 +507,9 @@ class ConfigRSS:
         self.pp = OptionStr(name, 'pp', '', add=False)
         self.script = OptionStr(name, 'script', add=False)
         self.enable = OptionBool(name, 'enable', add=False)
-        self.priority = OptionNumber(name, 'priority', constants.DEFAULT_PRIORITY, constants.DEFAULT_PRIORITY, 2, add=False)
+        self.priority = OptionNumber(name, 'priority', DEFAULT_PRIORITY, DEFAULT_PRIORITY, 2, add=False)
         self.filters = OptionFilters(name, 'filters', add=False)
-        self.filters.set([['', '', '', 'A', '*']])
+        self.filters.set([['', '', '', 'A', '*', DEFAULT_PRIORITY]])
 
         self.set_dict(values)
         add_to_database('rss', self.__name, self)
@@ -518,12 +530,12 @@ class ConfigRSS:
         """ Return a dictionary with all attributes """
         dict = {}
         dict['name'] = self.__name
-        dict['uri'] = self.uri.get()
-        dict['cat'] = self.cat.get()
-        dict['pp'] = self.pp.get()
-        dict['script'] = self.script.get()
-        dict['enable'] = self.enable.get()
-        dict['priority'] = self.priority.get()
+        dict['uri'] = self.uri()
+        dict['cat'] = self.cat()
+        dict['pp'] = self.pp()
+        dict['script'] = self.script()
+        dict['enable'] = self.enable()
+        dict['priority'] = self.priority()
         filters = self.filters.get_dict()
         for kw in filters:
             dict[kw] = filters[kw]
@@ -627,9 +639,9 @@ def read_config(path):
         # No file found, create default INI file
         try:
             if not sabnzbd.WIN32:
-                prev= os.umask(077)
+                prev = os.umask(077)
             fp = open(path, "w")
-            fp.write("__version__=%s\n[misc]\n[logging]\n" % __CONFIG_VERSION)
+            fp.write("__version__=%s\n[misc]\n[logging]\n" % CONFIG_VERSION)
             fp.close()
             if not sabnzbd.WIN32:
                 os.umask(prev)
@@ -639,15 +651,15 @@ def read_config(path):
     try:
         CFG = configobj.ConfigObj(path)
         try:
-            if int(CFG['__version__']) > int(__CONFIG_VERSION):
-                return False, "Incorrect version number %s in %s" %(CFG['__version__'], path)
-        except KeyError:
-            CFG['__version__'] = __CONFIG_VERSION
-        except ValueError:
-            CFG['__version__'] = __CONFIG_VERSION
+            if int(CFG['__version__']) > int(CONFIG_VERSION):
+                return False, "Incorrect version number %s in %s" % (CFG['__version__'], path)
+        except (KeyError, ValueError):
+            CFG['__version__'] = CONFIG_VERSION
     except configobj.ConfigObjError, strerror:
         return False, '"%s" is not a valid configuration file<br>Error message: %s' % (path, strerror)
 
+    CFG['__version__'] = CONFIG_VERSION
+
     if 'misc' in CFG:
         compatibility_fix(CFG['misc'])
 
@@ -675,6 +687,7 @@ def read_config(path):
 def save_config(force=False):
     """ Update Setup file with current option values """
     global CFG, database, modified
+    assert isinstance(CFG, configobj.ConfigObj)
 
     if not (modified or force):
         return True
@@ -683,7 +696,7 @@ def save_config(force=False):
         if section in ('servers', 'categories', 'rss'):
             try:
                 CFG[section]
-            except:
+            except KeyError:
                 CFG[section] = {}
             for subsec in database[section]:
                 if section == 'servers':
@@ -692,7 +705,7 @@ def save_config(force=False):
                     subsec_mod = subsec
                 try:
                     CFG[section][subsec_mod]
-                except:
+                except KeyError:
                     CFG[section][subsec_mod] = {}
                 items = database[section][subsec].get_dict()
                 CFG[section][subsec_mod] = items
@@ -702,9 +715,9 @@ def save_config(force=False):
                 sec = sec[-1]
                 try:
                     CFG[sec]
-                except:
+                except KeyError:
                     CFG[sec] = {}
-                value = database[section][option].get()
+                value = database[section][option]()
                 if type(value) == type(True):
                     CFG[sec][kw] = str(int(value))
                 elif type(value) == type(0):
@@ -712,19 +725,33 @@ def save_config(force=False):
                 else:
                     CFG[sec][kw] = value
 
+    filename = CFG.filename
     try:
-        CFG.write()
+        # Read current content
         f = open(CFG.filename)
-        x = f.read()
+        data = f.read()
         f.close()
-        f = open(CFG.filename, "w")
-        f.write(x)
-        f.flush()
+
+        # Write to temp file
+        CFG.filename = filename + '.tmp'
+        f = open(CFG.filename, 'w')
+        f.write(data)
         f.close()
+
+        # Update temp file content
+        CFG.write()
+
+        # Rename temp file, overwriting old one
+        os.remove(filename)
+        os.rename(CFG.filename, filename)
+
         modified = False
-        return True
-    except IOError:
-        return False
+        res = True
+    except:
+        logging.error(Ta('Cannot create temp file for %s'), CFG.filename)
+        res = False
+    CFG.filename = filename
+    return res
 
 
 
@@ -744,7 +771,7 @@ def get_servers():
     global database
     try:
         return database['servers']
-    except:
+    except KeyError:
         return {}
 
 
@@ -753,29 +780,44 @@ def define_categories(force=False):
         return a list of ConfigCat instances
     """
     global CFG, categories
-    cats = ['Unknown', 'Anime', 'Apps', 'Books', 'Consoles', 'Emulation', 'Games',
-            'Misc', 'Movies', 'Music', 'PDA', 'Resources', 'TV']
-
     try:
         for cat in CFG['categories']:
             ConfigCat(cat, CFG['categories'][cat])
     except KeyError:
-        force = True
+        pass
 
-    if force:
-        for cat in cats:
-            val = { 'newzbin' : cat, 'dir' : cat }
-            ConfigCat(cat.lower(), val)
 
-def get_categories():
-    global database
+def old_def(item, default):
+    """ Get old INI setting from [misc], if missing use 'default' """
     try:
-        return database['categories']
-    except:
-        return {}
+        return CFG['misc'][item]
+    except KeyError:
+        return default
+
+
+def get_categories(cat=0):
+    """ Return link to categories section.
+        This section will always contain special category '*'
+        When 'cat' is given, a link to that category or to '*' is returned
+    """
+    global database
+    if 'categories' not in database:
+        database['categories'] = {}
+    cats = database['categories']
+    if '*' not in cats:
+        ConfigCat('*', {'pp' : old_def('dirscan_opts', '3'), 'script' : old_def('dirscan_script', 'None'), \
+                        'priority' : old_def('dirscan_priority', NORMAL_PRIORITY)})
+        save_config(True)
+    if not isinstance(cat, int):
+        try:
+            cats = cats[cat]
+        except KeyError:
+            cats = cats['*']
+    return cats
+
 
 def define_rss():
-    """ Define rss-ffeds listed in the Setup file
+    """ Define rss-feeds listed in the Setup file
         return a list of ConfigRSS instances
     """
     global CFG
@@ -789,7 +831,7 @@ def get_rss():
     global database
     try:
         return database['rss']
-    except:
+    except KeyError:
         return {}
 
 def get_filename():
@@ -811,7 +853,7 @@ def encode_password(pw):
         encPW = __PW_PREFIX
         for c in pw:
             cnum = ord(c)
-            if c == '#' or cnum<33 or cnum>126:
+            if c == '#' or cnum < 33 or cnum > 126:
                 enc = True
             encPW += '%2x' % cnum
         if enc:
@@ -828,8 +870,8 @@ def decode_password(pw, name):
         for n in range(len(__PW_PREFIX), len(pw), 2):
             try:
                 ch = chr( int(pw[n] + pw[n+1], 16) )
-            except:
-                logging.error(Ta('error-encPw@1'), name)
+            except ValueError:
+                logging.error(Ta('Incorrectly encoded password %s'), name)
                 return ''
             decPW += ch
         return decPW
@@ -853,7 +895,7 @@ def validate_octal(value):
         int(value, 8)
         return None, value
     except:
-        return Ta('error-notOctal@1') % value, None
+        return Ta('%s is not a correct octal value') % value, None
 
 
 def validate_no_unc(root, value, default):
@@ -862,7 +904,7 @@ def validate_no_unc(root, value, default):
     if value and not value.startswith(r'\\'):
         return validate_notempty(root, value, default)
     else:
-        return Ta('error-noUNC@1') % value, None
+        return Ta('UNC path "%s" not allowed here') % value, None
 
 
 def validate_safedir(root, value, default):
@@ -870,7 +912,7 @@ def validate_safedir(root, value, default):
     if sabnzbd.empty_queues():
         return validate_no_unc(root, value, default)
     else:
-        return Ta('error-QnotEmpty'), None
+        return Ta('Error: Queue not empty, cannot change folder.'), None
 
 
 def validate_dir_exists(root, value, default):
@@ -879,7 +921,7 @@ def validate_dir_exists(root, value, default):
     if os.path.exists(p):
         return None, value
     else:
-        return Ta('error-noFolder@1') % p, None
+        return Ta('Folder "%s" does not exist') % p, None
 
 
 def validate_notempty(root, value, default):
@@ -891,6 +933,8 @@ def validate_notempty(root, value, default):
 
 
 def create_api_key():
+    """ Return a new randomized API_KEY
+    """
     import time
     try:
         from hashlib import md5
@@ -917,7 +961,7 @@ _FIXES = \
 )
 
 def compatibility_fix(cf):
-    # Convert obsolete entries
+    """ Convert obsolete INI entries """
     for item in _FIXES:
         old, new = item
         try:
