@@ -200,7 +200,7 @@ class NzbFile(TryList):
         """ Load the article objects from disk """
         logging.debug("Finishing import on %s", self.subject)
 
-        article_db = sabnzbd.load_data(self.nzf_id, self.nzo.workpath)
+        article_db = sabnzbd.load_data(self.nzf_id, self.nzo.workpath, remove=False)
         if article_db:
             for partnum in article_db:
                 art_id = article_db[partnum][0]
@@ -271,6 +271,13 @@ class NzbFile(TryList):
         """ Get lowest article number of this file """
         return min(self.decodetable)
 
+    def remove_admin(self):
+        """ Remove article database from disk (sabnzbd_nzf_<id>)"""
+        try:
+            os.remove(os.path.join(self.nzo.workpath, self.nzf_id))
+        except:
+            pass
+
     def __getstate__(self):
         """ Save to pickle file, translating attributes """
         dict_ = {}
@@ -297,7 +304,7 @@ class NzbFile(TryList):
 ################################################################################
 class NzbParser(xml.sax.handler.ContentHandler):
     """ Forgiving parser for NZB's """
-    def __init__ (self, nzo):
+    def __init__ (self, nzo, remove_samples=False):
         self.nzo = nzo
         assert isinstance(self.nzo, NzbObject)
         self.in_nzb = False
@@ -312,9 +319,10 @@ class NzbParser(xml.sax.handler.ContentHandler):
         self.skipped_files = 0
         self.nzf_list = []
         self.groups = []
+        self.filter = remove_samples
 
     def startDocument(self):
-        self.filter = cfg.ignore_samples()
+        pass
 
     def startElement(self, name, attrs):
         if name == 'segment' and self.in_nzb and self.in_file and self.in_segments:
@@ -338,7 +346,7 @@ class NzbParser(xml.sax.handler.ContentHandler):
             else:
                 self.filename = subject.strip()
 
-            if self.filter == 2 and RE_SAMPLE.search(subject):
+            if self.filter and RE_SAMPLE.search(subject):
                 logging.info('Skipping sample file %s', subject)
             else:
                 self.in_file = True
@@ -635,7 +643,7 @@ class NzbObject(TryList):
             if 'A&A)' in nzb:
                 # Fix needed to compensate for some dumb NZB posters
                 nzb = nzb.replace('A&A)', 'A&amp;A)')
-            handler = NzbParser(self)
+            handler = NzbParser(self, cfg.ignore_samples() == 2 and not reuse)
             parser = xml.sax.make_parser()
             parser.setFeature(xml.sax.handler.feature_external_ges, 0)
             parser.setContentHandler(handler)
