@@ -34,7 +34,7 @@ from sabnzbd.misc import real_path, get_unique_path, create_dirs, move_to_path,
                          get_unique_filename, make_script_path, \
                          on_cleanup_list, renamer, remove_dir, remove_all, globber
 from sabnzbd.tvsort import Sorter
-from sabnzbd.constants import TOP_PRIORITY, POSTPROC_QUEUE_FILE_NAME, \
+from sabnzbd.constants import REPAIR_PRIORITY, POSTPROC_QUEUE_FILE_NAME, \
      POSTPROC_QUEUE_VERSION, sample_match, JOB_ADMIN
 from sabnzbd.encoding import TRANS, unicoder
 from sabnzbd.newzbin import Bookmarks
@@ -88,6 +88,8 @@ class PostProcessor(Thread):
         self.history_queue = []
         logging.info("Loading postproc queue")
         data = sabnzbd.load_admin(POSTPROC_QUEUE_FILE_NAME)
+        if data is None:
+            return
         try:
             version, history_queue = data
             if POSTPROC_QUEUE_VERSION != version:
@@ -138,21 +140,39 @@ class PostProcessor(Thread):
         """ Return list of NZOs that still need to be processed """
         return [nzo for nzo in self.history_queue if nzo.work_name]
 
+    def get_path(self, nzo_id):
+        """ Return download path for given nzo_id or None when not found """
+        for nzo in self.history_queue:
+            if nzo.nzo_id == nzo_id:
+                return nzo.downpath
+        return None
+
     def run(self):
         """ Actual processing """
-        while 1:
+        check_eoq = False
+
+        while not self.__stop:
             self.__busy = False
-            if self.queue.empty(): handle_empty_queue()
 
-            while (not self.__stop) and self.paused:
+            if self.paused:
                 time.sleep(5)
+                continue
 
-            ## Get a job from the queue, quit on empty job
-            nzo = self.queue.get()
-            if not nzo: break
+            try:
+                nzo = self.queue.get(timeout=3)
+            except Queue.Empty:
+                if check_eoq:
+                    check_eoq = False
+                    handle_empty_queue()
+                continue
 
-            ## This job was already deleted.
+            ## Stop job
+            if not nzo:
+                continue
+
+            ## Job was already deleted.
             if not nzo.work_name:
+                check_eoq = True
                 continue
 
             ## Flag NZO as being processed
@@ -166,6 +186,7 @@ class PostProcessor(Thread):
             self.__busy = True
             if process_job(nzo):
                 self.remove(nzo)
+            check_eoq = True
 
             ## Allow download to proceed
             sabnzbd.downloader.Downloader.do.resume_from_postproc()
@@ -321,7 +342,11 @@ def process_job(nzo):
                 cleanup_list(tmp_workdir_complete, True)
 
                 ## Check if this is an NZB-only download, if so redirect to queue
-                nzb_list = nzb_redirect(tmp_workdir_complete, nzo.final_name, nzo.pp, script, cat, priority=nzo.priority)
+                ## except when PP was Download-only
+                if flag_repair:
+                    nzb_list = nzb_redirect(tmp_workdir_complete, nzo.final_name, nzo.pp, script, cat, priority=nzo.priority)
+                else:
+                    nzb_list = None
                 if nzb_list:
                     nzo.set_unpack_info('Download', T('Sent %s to queue') % unicoder(nzb_list))
                     try:
@@ -497,8 +522,7 @@ def parring(nzo, workdir):
 
         if re_add:
             logging.info('Readded %s to queue', filename)
-            sabnzbd.QUEUECOMPLETEACTION_GO = False
-            nzo.priority = TOP_PRIORITY
+            nzo.priority = REPAIR_PRIORITY
             sabnzbd.nzbqueue.add_nzo(nzo)
             sabnzbd.downloader.Downloader.do.resume_from_postproc()
 
@@ -575,7 +599,7 @@ def addPrefixes(path, dirprefix):
 
 def handle_empty_queue():
     """ Check if empty queue calls for action """
-    if sabnzbd.QUEUECOMPLETEACTION_GO:
+    if sabnzbd.nzbqueue.NzbQueue.do.actives() == 0:
         sabnzbd.save_state()
         logging.info("Queue has finished, launching: %s (%s)", \
             sabnzbd.QUEUECOMPLETEACTION, sabnzbd.QUEUECOMPLETEARG)
@@ -584,7 +608,6 @@ def handle_empty_queue():
         else:
             Thread(target=sabnzbd.QUEUECOMPLETEACTION).start()
 
-        sabnzbd.QUEUECOMPLETEACTION_GO = False
         sabnzbd.change_queue_complete_action(cfg.queue_complete(), new=False)
 
 
@@ -596,15 +619,18 @@ def cleanup_list(wdir, skip_nzb):
             files = os.listdir(wdir)
         except:
             files = ()
-        for file_ in files:
-            if on_cleanup_list(file_, skip_nzb):
-                path = os.path.join(wdir, file_)
-                try:
-                    logging.info("Removing unwanted file %s", path)
-                    os.remove(path)
-                except:
-                    logging.error(Ta('Removing %s failed'), path)
-                    logging.info("Traceback: ", exc_info = True)
+        for file in files:
+            path = os.path.join(wdir, file)
+            if os.path.isdir(path):
+                cleanup_list(path, skip_nzb)
+            else:
+                if on_cleanup_list(file, skip_nzb):
+                    try:
+                        logging.info("Removing unwanted file %s", path)
+                        os.remove(path)
+                    except:
+                        logging.error(Ta('Removing %s failed'), path)
+                        logging.info("Traceback: ", exc_info = True)
 
 
 def prefix(path, pre):
