@@ -23,6 +23,8 @@ import re
 import logging
 import time
 import threading
+import urllib
+import os
 
 import sabnzbd
 from sabnzbd.constants import *
@@ -298,6 +300,12 @@ class RSSQueue(object):
                 logging.info(msg)
                 return unicoder(msg)
 
+            status = d.get('status', 999)
+            if status in (401, 402, 403):
+                msg = Ta('Do not have valid authentication for feed %s') % feed
+                logging.info(msg)
+                return unicoder(msg)
+
             entries = d.get('entries')
             if 'bozo_exception' in d and not entries:
                 msg = Ta('Failed to retrieve RSS from %s: %s') % (uri, xml_name(str(d['bozo_exception'])))
@@ -337,8 +345,12 @@ class RSSQueue(object):
                 title = unicoder(atitle)
 
             if link:
-                # Make sure there are no spaces in the URL
-                link = link.replace(' ','')
+                # Make sure spaces are quoted in the URL
+                if 'nzbclub.com' in link:
+                    link, path = os.path.split(link.strip())
+                    link = '%s/%s' % (link, urllib.quote(path))
+                else:
+                    link = link.strip().replace(' ','%20')
 
                 newlinks.append(link)
 
