@@ -42,6 +42,7 @@ SKIN_TEXT = {
     'post-Verifying'     : TT('Verifying...'), #: PP status
     'post-Downloading'   : TT('Downloading'), #: Pseudo-PP status, in reality used for Queue-status
     'post-Grabbing'      : TT('Get NZB'), #: Pseudo-PP status, in reality used for Grabbing status
+    'post-Checking'      : TT('Checking'), #: PP status
 
     'sch-frequency'      : TT('Frequency'), #:  #: Config->Scheduler
     'sch-action'         : TT('Action'), #:  #: Config->Scheduler
@@ -115,6 +116,7 @@ SKIN_TEXT = {
     'cmenu-servers' : TT('Servers'), #: Main menu item
     'cmenu-scheduling' : TT('Scheduling'), #: Main menu item
     'cmenu-rss' : TT('RSS'), #: Main menu item
+    'cmenu-emailN' : TT('Notifications'), #: Main menu item
     'cmenu-email' : TT('Email'), #: Main menu item
     'cmenu-newzbin' : TT('Index Sites'), #: Main menu item
     'cmenu-cat' : TT('Categories'), #: Main menu item
@@ -154,6 +156,7 @@ SKIN_TEXT = {
     'pp-u' : TT('U'),
     'pp-d' : TT('D'),
     'pr-force' : TT('Force'),
+    'pr-repair' : TT('Repair'),
     'pr-normal' : TT('Normal'),
     'pr-high' : TT('High'),
     'pr-low' : TT('Low'),
@@ -194,6 +197,7 @@ SKIN_TEXT = {
     'removeNZB-Files' : TT('Remove NZB & Delete Files'), #: Queue page button
     'AofB' : TT('of'), #: Queue page, as in "4G *of* 10G"
     'missingArt': TT('Missing articles'), #: Caption for missing articles in Queue
+    'quotum-left' : TT('Quotum left'), #: Remaining quotum (displayed in Queue)
 
 # History page
     'purgeHist' : TT('Purge History'), #: History page button
@@ -419,6 +423,17 @@ SKIN_TEXT = {
     'swtag-queue' : TT('Queue'),
     'swtag-pp' : TT('Post processing'),
     'swtag-naming' : TT('Naming'),
+    'swtag-quotum' : TT('Quotum'),
+    'opt-quotum_size' : TT('Size'), #: Size of the download quotum
+    'explain-quotum_size' : TT('How much can be downloaded this month (K/M/G)'),
+    'opt-quotum_day' : TT('Reset day'), #: Reset day of the download quotum
+    'explain-quotum_day' : TT('On which day of the month or week (1=Monday) does your ISP reset the quotum? (Optionally with hh:mm)'),
+    'opt-quotum_resume' : TT('Auto resume'), #: Auto-resume download on the reset day
+    'explain-quotum_resume' : TT('Should downloading resume after the quotum is reset?'),
+    'opt-quotum_period' : TT('Quotum period'), #: Does the quotum get reset every day, week or month?
+    'explain-quotum_period' : TT('Does the quotum get reset each day, week or month?'),
+    'opt-pre_check' : TT('Check before download'),
+    'explain-pre_check' : TT('Try to predict successful completion before actual download (slower!)'),
 
 
 # Config->Server
@@ -485,12 +500,12 @@ SKIN_TEXT = {
     'filters' : TT('Filters'), #: Tab title for Config->Feeds
 
 # Config->Email
-    'configEmail' : TT('Email Notification'),
-    'emailOptions' : TT('Email Options'),
+    'configEmail' : TT('Email Notifications'), #: Main Config page
+    'emailOptions' : TT('Email Options'), #: Section header
     'opt-email_endjob' : TT('Email Notification On Job Completion'),
-    'email-never' : TT('Never'),
-    'email-always' : TT('Always'),
-    'email-errorOnly' : TT('Error-only'),
+    'email-never' : TT('Never'), #: When to send email
+    'email-always' : TT('Always'),  #: When to send email
+    'email-errorOnly' : TT('Error-only'),  #: When to send email
     'opt-email_full' : TT('Disk Full Notifications'),
     'explain-email_full' : TT('Send email when disk is full and SABnzbd is paused.'),
     'opt-email_rss' : TT('Send RSS notifications'),
@@ -506,6 +521,16 @@ SKIN_TEXT = {
     'explain-email_account' : TT('For authenticated email, account name.'),
     'opt-email_pwd' : TT('OPTIONAL Account Password'),
     'explain-email_pwd' : TT('For authenticated email, password.'),
+    'growlSettings' : TT('Notifications'), #: Section header
+    'opt-growl_enable' : TT('Enable Growl'), #: Don't translate "Growl"
+    'explain-growl_enable' : TT('Send notifications to Growl'), #: Don't translate "Growl"
+    'opt-growl_server' : TT('Server address'), #: Address of Growl server
+    'explain-growl_server' : TT('Only use for remote Growl server (host:port)'), #: Don't translate "Growl"
+    'opt-growl_password' : TT('Server password'), #: Growl server password
+    'explain-growl_password' : TT('Optional password for Growl server'), #: Don't translate "Growl"
+    'opt-ntfosd_enable' : TT('Enable NotifyOSD'), #: Don't translate "NotifyOSD"
+    'explain-ntfosd_enable' : TT('Send notifications to NotifyOSD'), #: Don't translate "NotifyOSD"
+    'testNotify' : TT('Test Notification'),
 
 # Config->Newzbin
     'explain-newzbin' : TT('If you have an account at <strong>www.newzbin.com</strong>, you can enter your account info here.<br />This will unlock extra functionality.'),
@@ -741,6 +766,7 @@ SKIN_TEXT = {
     'smpl-downloading' : TT('Downloading'),
     'smpl-idle' : TT('Idle'),
     'smpl-emailsent' : TT('Email Sent!'),
+    'smpl-notesent' : TT('Notification Sent!'),
     'smpl-saving' : TT('Saving..'),
     'smpl-saved' : TT('Saved'),
     'smpl-failed' : TT('Failed'),
