@@ -28,7 +28,7 @@ For more control you can use one of the following Task classes
 and use schedule_task or schedule_task_abs:
 
     IntervalTask    ThreadedIntervalTask    ForkedIntervalTask
-    SingleTask      ThreadedSingleTask      ForkedSingleTask 
+    SingleTask      ThreadedSingleTask      ForkedSingleTask
     WeekdayTask     ThreadedWeekdayTask     ForkedWeekdayTask
     MonthdayTask    ThreadedMonthdayTask    ForkedMonthdayTask
 
@@ -80,6 +80,7 @@ import sched
 import time
 import traceback
 import weakref
+import logging
 
 class method:
     sequential="sequential"
@@ -123,8 +124,8 @@ class Scheduler:
     def add_interval_task(self, action, taskname, initialdelay, interval,
             processmethod, args, kw):
         """Add a new Interval Task to the schedule.
-        
-        A very short initialdelay or one of zero cannot be honored, you will 
+
+        A very short initialdelay or one of zero cannot be honored, you will
         see a slight delay before the task is first executed. This is because
         the scheduler needs to pick it up in its loop.
 
@@ -148,7 +149,7 @@ class Scheduler:
         self.schedule_task(task, initialdelay)
         return task
 
-    def add_single_task(self, action, taskname, initialdelay, processmethod, 
+    def add_single_task(self, action, taskname, initialdelay, processmethod,
             args, kw):
         """Add a new task to the scheduler that will only be executed once."""
         if initialdelay < 0:
@@ -170,7 +171,7 @@ class Scheduler:
         self.schedule_task(task, initialdelay)
         return task
 
-    def add_daytime_task(self, action, taskname, weekdays, monthdays, timeonday, 
+    def add_daytime_task(self, action, taskname, weekdays, monthdays, timeonday,
             processmethod, args, kw):
         """Add a new Day Task (Weekday or Monthday) to the schedule."""
         if weekdays and monthdays:
@@ -210,9 +211,9 @@ class Scheduler:
 
     def schedule_task(self, task, delay):
         """Add a new task to the scheduler with the given delay (seconds).
-        
+
         Low-level method for internal use.
-        
+
         """
         if self.running:
             # lock the sched queue, if needed
@@ -228,9 +229,9 @@ class Scheduler:
 
     def schedule_task_abs(self, task, abstime):
         """Add a new task to the scheduler for the given absolute time value.
-        
+
         Low-level method for internal use.
-        
+
         """
         if self.running:
             # lock the sched queue, if needed
@@ -268,7 +269,7 @@ class Scheduler:
         def _getqueuetoptime(self):
             return self.sched.queue[0][0]
         def _clearschedqueue(self):
-            self.sched.queue[:] = []                    
+            self.sched.queue[:] = []
 
     def _run(self):
         # Low-level run method to do the actual scheduling loop.
@@ -276,10 +277,7 @@ class Scheduler:
             try:
                 self.sched.run()
             except Exception,x:
-                print >>sys.stderr, "ERROR DURING SCHEDULER EXECUTION",x
-                print >>sys.stderr, "".join(
-                    traceback.format_exception(*sys.exc_info()))
-                print >>sys.stderr, "-" * 20
+                logging.error("ERROR DURING SCHEDULER EXECUTION %s" % str(x), exc_info=True)
             # queue is empty; sleep a short while before checking again
             if self.running:
                 time.sleep(5)
@@ -314,9 +312,7 @@ class Task:
 
     def handle_exception(self, exc):
         """Handle any exception that occured during task execution."""
-        print >>sys.stderr, "ERROR DURING TASK EXECUTION", exc
-        print >>sys.stderr, "".join(traceback.format_exception(*sys.exc_info()))
-        print >>sys.stderr, "-" * 20
+        logging.error("ERROR DURING SCHEDULER EXECUTION %s" % str(exc), exc_info=True)
 
 
 class SingleTask(Task):
@@ -363,7 +359,7 @@ class DayTaskRescheduler:
 
     def reschedule(self, scheduler):
         """Reschedule this task according to the daytime for the task.
-        
+
         The task is scheduled for tomorrow, for the given daytime.
 
         """
@@ -376,7 +372,7 @@ class DayTaskRescheduler:
 class WeekdayTask(DayTaskRescheduler, Task):
     """A task that is called at specific days in a week (1-7), at a fixed time
     on the day.
-    
+
     """
 
     def __init__(self, name, weekdays, timeonday, action, args=None, kw=None):
@@ -398,9 +394,9 @@ class WeekdayTask(DayTaskRescheduler, Task):
 
 
 class MonthdayTask(DayTaskRescheduler, Task):
-    """A task that is called at specific days in a month (1-31), at a fixed 
+    """A task that is called at specific days in a month (1-31), at a fixed
     time on the day.
-    
+
     """
 
     def __init__(self, name, monthdays, timeonday, action, args=None, kw=None):
@@ -436,7 +432,7 @@ try:
             self.thread = threading.Thread(target=self._run)
             self.thread.setDaemon(True)
             self.thread.start()
-            
+
         def stop(self):
             """Stop the scheduler and wait for the thread to finish."""
             Scheduler.stop(self)
@@ -448,7 +444,7 @@ try:
         def _acquire_lock(self):
             """Lock the thread's task queue."""
             self._lock.acquire()
-            
+
         def _release_lock(self):
             """Release the lock on th ethread's task queue."""
             self._lock.release()
@@ -475,7 +471,7 @@ try:
         pass
 
     class ThreadedSingleTask(ThreadedTaskMixin, SingleTask):
-        """Single Task that executes in its own thread.""" 
+        """Single Task that executes in its own thread."""
         pass
 
     class ThreadedWeekdayTask(ThreadedTaskMixin, WeekdayTask):
@@ -569,11 +565,11 @@ if __name__=="__main__":
     s=ThreadedScheduler()
     s.add_interval_task( testaction, "test action 1", 0, 4, method.threaded, ["task 1"], None )
     s.start()
-    
+
     print "Scheduler started, waiting 15 sec...."
     time.sleep(15)
-    
+
     print "STOP SCHEDULER"
     s.stop()
-    
+
     print "EXITING"
